Module: Logify::ClassMethods

Defined in:
lib/logify.rb

Overview

Class methods that get extended into any including object.

Instance Method Summary collapse

Instance Method Details

#logLogger

Write a message to the logger for this class.

Returns:



108
109
110
# File 'lib/logify.rb', line 108

def log
  @log ||= Logify.logger_for(name)
end